==> haskell-x509-store-1.6.1-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509-store/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.1
id: x509-store-1.6.1-43770428c1088301ba6ed013a258fa1c
key: x509s_IPucgn5P9MCKF9LmNT0EcL
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-store-1.6.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-store-1.6.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-store-1.6.1
hs-libraries: HSx509-store-1.6.1-IPucgn5P9MCKF9LmNT0EcL
depends:
    asn1-encoding-0.9.3-61b8646033da9bb10b3d5eef2c9988e8
    asn1-types-0.3.2-373d90c7a1b36e8b9d0fe76023835d30
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.10-0b27873a24b130f970d262828e1e69fa
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    x509-1.6.3-88141428fd098325953c29fe36fd878e
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.1-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509-store/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.1
id: x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
key: x509s_06kDFiYO8RLIM2QbtkDQy0
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-store-1.6.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-store-1.6.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-store-1.6.1
hs-libraries: HSx509-store-1.6.1-06kDFiYO8RLIM2QbtkDQy0
depends:
    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
    asn1-types-0.3.2-3969820adc8283f126affe054010f830
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
